@@ -56,12 +56,12 @@ class MicroblogConfig(ConfigParser):
                 print('Error in the interval setting')
                 sys.exit(1)
             try:
-                config['consumer_key'] = self.get("global","consumer_key").strip()
+                config['consumer_key'] = self.get(section,"consumer_key").strip()
             except:
                 print('Error in the consumer_key setting')
                 sys.exit(1)
             try:
-                config['consumer_secret'] = self.get("global","consumer_secret").strip()
+                config['consumer_secret'] = self.get(section,"consumer_secret").strip()
             except:
                 print('Error in the consumer_secret setting')
                 sys.exit(1)
