@@ -39,18 +39,22 @@ class Microblog(object):
         if not lastread:
             log.info ("There's no record of previous update on " + self.alias)
             log.info ('new items to update: ' + str(self.items))
-            self.postIt(reversed(self.rss.feed['items'][:self.items]))
+
+            items = self.rss.feed['items'][:self.items]
+            items.reverse()
+            self.postIt(items)
         else:
             try:
                 lista = [item for item in self.rss.feed['items'] if item['published_parsed'] > lastread]
             except:
                 lista = [item for item in self.rss.feed['items'] if item['updated_parsed'] > lastread]
+            lista.reverse()
             log.info ('items to update: ' + str(len(lista)))
-            self.postIt(reversed(lista[:self.items]))
+            self.postIt(lista)
 
     def postIt(self, items):
         oldItems = pItems = 0
-        for it in list(items):
+        for it in items:
             if self.mode == 'title':
                 try:
                     short_address = self.shortener.short(it["link"])	   
@@ -72,9 +76,9 @@ class Microblog(object):
                 time.sleep(5)
 
             except (TweepError), e:
+                log.debug(e.reason)
                 try:
-                    log.debug(e.reason + ' - ' + txt)
-                    if e.reason == 'Status is a duplicate.' or e.reason == 'Twitter error response: status code = 411':
+                    if e.reason == 'Status is a duplicate.':
                         self.rss.updateLastRead(it)
                 except:
                     pass
